PreparedFetch

Struct PreparedFetch 

pub struct PreparedFetch<T, E> {
    pub entity: Entity<QueryResource<T, E>>,
    pub request_id: RequestId,
    pub signal: QuerySignal,
    /* private fields */
}
Available on crate feature client only.
A prepared fetch returned by [QueryClient::prepare_fetch_query] or [QueryClient::prepare_prefetch_query].

Contains the entity, request ID, and cooperative cancellation signal needed to perform the async fetch and complete the resource.

The caller should:

  1. Call their fetcher with self.signal
  2. Use complete_success or complete_failure with the result

Example

use gpui_query::client::QueryClient;
use gpui_query::core::QueryKey;

let prepared = client.prepare_fetch_query::<Data, Error>(key, cx).unwrap();
let signal = prepared.signal.clone();
// Use cx.spawn() to run your async fetcher with the signal, then call
// prepared.complete_success(data, cx) or prepared.complete_failure(e, cx).

Fields

entity: Entity<QueryResource<T, E>>

The query resource entity.

request_id: RequestId

The request ID for the started request.

signal: QuerySignal

The cooperative cancellation signal for the in-flight request.

Implementations

Source

impl<T: Clone + Send + Sync + 'static, E: Clone + Send + Sync + 'static> PreparedFetch<T, E>

pub fn complete_success(self, data: T, cx: &mut App)

Complete the fetch with success.

Calls complete_current_success on the resource entity. If the request ID is no longer active (replaced by a newer request), this is a no-op.

M3: reuses the now_ms captured at prepare time instead of re-syscalling current_time_ms().

pub fn complete_failure(self, error: E, cx: &mut App)

Complete the fetch with failure.

Calls complete_current_failure on the resource entity. If the request ID is no longer active (replaced by a newer request), this is a no-op.

M3: reuses the now_ms captured at prepare time instead of re-syscalling current_time_ms().