pub enum QueryBeginResult {
Started {
request_id: RequestId,
status: QueryStatus,
replaced_request_id: Option<RequestId>,
},
CacheHit,
StaleCacheHit {
request_id: RequestId,
status: QueryStatus,
replaced_request_id: Option<RequestId>,
},
IgnoredWhileLoading {
active_request_id: RequestId,
},
}Available on crate feature
core only.Expand description
The result of calling begin_request on a query resource.
Variants
Started
A new request was started.
CacheHit
Cache is fresh — no fetch needed.
StaleCacheHit
Stale data was served and a background revalidation was started.
The caller should:
- Return the existing stale data to the consumer immediately.
- Use the
request_idto perform a background fetch. - Complete the request normally via
complete_success/complete_failure.
IgnoredWhileLoading
A request is already loading and the policy is IgnoreWhileLoading.